#!/bin/sh
#
#    Copyright (c) 1996-2004 by Brocade Communications Systems, Inc.
#    All rights reserved.
#
#    wwninit.sh

#
# MFG SEEPROM Initialization script (WWN)
#
# 02/20/04    initial version
#

######################################################################
# constants
maxPN=14 # max PN char can be entered (13 + <cr>)
maxSN=12 # max SN char can be entered (11 + <cr>)

wwn1=10
wwn2=00
wwn3=00
wwn4=60
wwn5=69
wwn6=00
wwn7=00
wwn8=00

oui1=10
oui2=00

default_PN="60-0005986-01"
default_SN="13460999"
default_OUI="006069"        # default WWN OUI
######################################################################

######################################################################
#  utility functions
######################################################################

#
# userInputPL()
#
# $1 : display name for input
# $2 : default value
userInputPL()
{
    ##################################################################
    # do nothing if the variable is set
    if [ $boardPL != 0 ]
    then
	return
    fi
    ##################################################################

    ##################################################################
    # set the platform with default value
    boardPL=`getSWBD`
    ##################################################################
}

#
# userInputPN()
#
# $1 : display name for input
# $2 : default value
userInputPN()
{
    ##################################################################
    # do nothing if the variable is set
    if [ $boardPN != 0 ]
    then
	return
    fi
    ##################################################################

    ##################################################################
    # get input from user
    echo "Enter $1 (max 13 char)[$2]:"
    read line
    ##################################################################

    if [ $line ]
    then
	##############################################################
	# check input format
	nc=`echo $line | wc -c`
	if [ $nc -gt $maxPN ]
	then
	    echo "$2 input exceeded 13 characters."
	    exit 1
	else
	    boardPN=$line
	fi
	##############################################################
    else
	echo "No $1 entered, default to $2."
	boardPN=$2
    fi
}

#
# userInputOUI()
#
# $1 : display name for input
# $2 : default value
userInputOUI()
{
    ##################################################################
    # do nothing if the variable is set
    if [ $boardOUI != 0 ]
    then
	return
    fi
    ##################################################################

    ##################################################################
    # set the platform with default value
    boardOUI=$2
    ##################################################################
}


#
# userInputSN()
#
# $1 : display name for input
# $2 : default value
userInputSN()
{
    ##################################################################
    # do nothing if the variable is set
    if [ $boardSN != 0 ]
    then
	return
    fi
    ##################################################################

    ##################################################################
    # get input from user
    echo "Enter $1 (max 11 char)[$2]:"
    read line
    ##################################################################

    if [ $line ]
    then
	##############################################################
	# check input format
	nc=`echo $line | wc -c`
	if [ $nc -gt $maxSN -o $nc -lt 6 ]
	then
	    echo "$2 input invalid length (6 - 11 characters required)."
	    exit
	else
	    boardSN=$line
	fi
	##############################################################
    else
	echo "No $1 entered, default to $2."
	boardSN=$2
    fi
}


#
# userInputWWN()
#
# $1 : display name for input
# $2 : default value
userInputWWN()
{
    count=0
    ##################################################################
    #  input a line from user
    echo "Enter last 6 digits of WWN (6 char - default $2)"
    read line
    ##################################################################

    if [ $line ]
    then

	##############################################################
	#  count char entered
	nc=`echo $line | wc -c`
	##############################################################

	##############################################################
	#  make sure input is 6 char + return
	if [ $nc -ne 7 ]
	then
	    export boardWWN=$default_WWN
	    echo "$1 Input invalid length $nc (6 char required)."
	    exit 1
	fi
	##############################################################

	export boardWWN=$line
    else
	echo "No WWN entered, defaulting to $2."
	export boardWWN=$2	
    fi
}


#
# userInputLID()
#
# $1 : display name for input
# $2 : default value
userInputLID()
{
    count=0
    ##################################################################
    #  input a line from user
    echo "Enter License Id (16 char - default $2)"
    read line
    ##################################################################

    if [ $line ]
    then
	#  count char entered
	#
	nc=`echo $line | wc -c`

	#  make sure input is 16 char (plus <cr> char)
	#
	if [ $nc -ne 17 ]
	then
	    lid=$default_LID
	    echo "$1 input invalid length $nc (16 char required)."
	    exit 1
	fi

	export lid1=`echo $line | cut -c1-2`
	export lid2=`echo $line | cut -c3-4`
	export lid3=`echo $line | cut -c5-6`
	export lid4=`echo $line | cut -c7-8`
	export lid5=`echo $line | cut -c9-10`
	export lid6=`echo $line | cut -c11-12`
	export lid7=`echo $line | cut -c13-14`
	export lid8=`echo $line | cut -c15-16`
	
    else
	echo "No $1 entered, defaulting to $2."
	export lid1=`echo $2 | cut -c1-2`
	export lid2=`echo $2 | cut -c3-4`
	export lid3=`echo $2 | cut -c5-6`
	export lid4=`echo $2 | cut -c7-8`
	export lid5=`echo $2 | cut -c9-10`
	export lid6=`echo $2 | cut -c11-12`
	export lid7=`echo $2 | cut -c13-14`
	export lid8=`echo $2 | cut -c15-16`
    fi
}

#
# process_command()
#
# $* : command line
process_command()
{
    local message
    message=$1
    shift

    $*
    stat=$?

    if [ $stat -ne 0 ]
    then
	echo "FRUINIT ERROR : $*"
    fi

    stat=`/fabos/bin/expr $status + $stat`
}


######################################################################
#  main
######################################################################

######################################################################
# source diagcommon
home="/fabos/share"
util="diagcommon.sh"
ok=0
for f in "./$util" "$FABOSHOME/share/$util" "$home/$util" ; do
    if [ -r $f ] ; then
	. $f
	ok=1
	break;
    fi
done
if [ $ok -ne 1 ] ; then
    err "Could not locate $util"
    exit 3
fi
######################################################################

#
# variables
#
boardPL=0  # platform
boardPN=$default_PN  # board PN
boardSN=$default_SN  # board SN
boardOUI=0 # board OUI
mfgDate=0  # manufacture date
mfgMonth=0 # manufacture month
mfgYear=0  # manufacture year

status=0

# last six digits of WWN
wwn6=0
wwn7=0
wwn8=0

# find fruinit command
cmd=`commandPath fruinit`

#
#  command line parsing
#
while [ $# != 0 ]
do
    case $1 in 

    ver)  
	echo "wwninit.sh : version 0.5"
	exit 0
	;;

    help)
	echo "wwninit.sh : script to init WWN"
	echo " "
	echo "Usage: wwninit.sh [help] [ver] [-p <swbd>] [-pn <n>] [-sn <n>] [-dd <n>] [-mm <n>][-yy <n>]"
	echo "	where:"
	echo "	  help          Display Usage"
	echo "	  ver           Version"
	echo "	  -p		Platform"
	echo "	  -pn <n>       WWN part number"
	echo "	  -sn <n>       WWN serial number"
	echo "	  -dd <n>	Manufacture Date [system]"
	echo "	  -mm <n>	Manufacture Month [system]"
	echo "	  -yy <n>	Manufacture Year [system]"
	echo "	  -oui <n>      WWN OUI Number [$default_OUI]"
	echo " "
	exit 0
	;;

    -p)  # platform
	shift
	if [ $1 ]
	then
	    boardPL=$1
	else
	    ArgErr="-p"
	fi
	;;
	
    -pn) # WWN board part number
	shift
	if [ $1 ]
	then
	    boardPN=$1
	else
	    ArgErr="-pn"
	fi
	;;

    -sn) # WWN board serial number
	shift
	if [ $1 ]
	then
	    boardSN=$1

	    ##########################################################
	    # input validity check(11 char max)
	    nc=`echo $boardSN | wc -c`
	    if [ $nc -gt $maxSN -o $nc -lt 6 ]
	    then
		boardSN=0
		ArgErr="-sn"
	    fi
	    ##########################################################
	else
	    ArgErr="-sn"
	fi
	;;

    -dd) # MFG date
	shift
	if [ $1 ]
	then
	    mfgDate=$1
	else
	    ArgErr="-dd"
	fi
	;;

    -mm) # MFG month
	shift
	if [ $1 ]
	then
	    mfgMonth=$1
	else
	    ArgErr="-mm"
	fi
	;;

    -yy) # MFG year
	shift
	if [ $1 ]
	then
	    mfgYear=$1
	else
	    ArgErr="-yy"
	fi
	;;

    -oui)
	shift
	if [ $1 ]
	then
	    boardOUI=$1
	    nc=`echo $boardOUI | wc -c`

	    ##########################################################
	    # input validity check(6 chars + return)
	    if [ $nc -ne 7 ]
	    then
		boardOUI=0
		ArgErr="-oui"
	    fi
	    ##########################################################
	else
	    ArgErr="-oui"
	fi
	;;

    *)
	echo "ERROR:  ABORTED - Invalid token <$1> entered"
	exit 1
	;;

    esac

    ##################################################################
    # check for error condition
    if test $ArgErr
    then
	echo "ERROR: ABORTED - Token <$ArgErr> requires an arg token"
	exit 1
    fi
    ##################################################################

    shift
done


#
#  commence script operation
#

######################################################################
# calculate date information if not available
if [ $mfgMonth = 0 ]
then
    mfgMonth=`/bin/date '+ %m' | sed "s/ 0/ /g" | sed "s/ //g"`
fi

if [ $mfgDate = 0 ]
then
    mfgDate=`/bin/date '+ %d' | sed "s/ 0/ /g" | sed "s/ //g"`
fi

if [ $mfgYear = 0 ]
then
    tempYear=`/bin/date '+ %y'`
    mfgYear=`/fabos/bin/expr $tempYear + 2000`
fi
######################################################################


######################################################################
#  get Platform & OUI
userInputPL "Platform" # set value (no user input)
userInputOUI "MAC OUI" $default_OUI
######################################################################

######################################################################
#  get PN & SN
userInputPN "WWN PN" $default_PN
userInputSN "WWW SN" $default_SN
######################################################################

######################################################################
#  construct default WWN & get last 6 digits of WWN
last_digit=`echo $boardSN | wc -c | tr -s " " " " | cut -d" " -f2`
first_digit=`/fabos/bin/expr $last_digit - 6`
default_WWN=`echo $boardSN | cut -c$first_digit-$last_digit`
userInputWWN "WWN" $default_WWN
######################################################################

######################################################################
#  construct default LID & get LID
default_LID="$oui1$oui2$boardOUI$boardWWN"
userInputLID "License ID" $default_LID
######################################################################


######################################################################
#  construct WWN/LID format for fruinit input

export wwn3=`echo $boardOUI | cut -c1-2`
export wwn4=`echo $boardOUI | cut -c3-4`
export wwn5=`echo $boardOUI | cut -c5-6`

export wwn6=`echo $boardWWN | cut -c1-2`
export wwn7=`echo $boardWWN | cut -c3-4`
export wwn8=`echo $boardWWN | cut -c5-6`

wwn="$wwn1:$wwn2:$wwn3:$wwn4:$wwn5:$wwn6:$wwn7:$wwn8"
lid="$lid1:$lid2:$lid3:$lid4:$lid5:$lid6:$lid7:$lid8"
######################################################################

#
#  execute fruinit with parameters
#
process_command "" $cmd -p $boardPL -c INIT    -t WWN -u 1
process_command "" $cmd -p $boardPL -c INITSIG -t WWN -u 1

process_command "" $cmd -p $boardPL -c SET -t WWN -u 1 -k PARTNO -v $boardPN
process_command "" $cmd -p $boardPL -c SET -t WWN -u 1 -k SERIAL -v $boardSN
process_command "" $cmd -p $boardPL -c SET -t WWN -u 1 -k MFGDAY   -v $mfgDate
process_command "" $cmd -p $boardPL -c SET -t WWN -u 1 -k MFGMONTH -v $mfgMonth
process_command "" $cmd -p $boardPL -c SET -t WWN -u 1 -k MFGYEAR  -v $mfgYear

process_command "" $cmd -p $boardPL -c WWNCONFCLR

# CP WWN configuration
process_command "" $cmd -p $boardPL -c WWNINIT -t CP -u 1
process_command "" $cmd -p $boardPL -c WWNCONF -t CP -u 1 -k LICENSEID -v $lid

# SW(1) WWN configuration
process_command "" $cmd -p $boardPL -c WWNINIT -t SW -u 1
process_command "" $cmd -p $boardPL -c WWNCONF -t SW -u 1 -k LICENSEID -v $wwn

# SW(2) WWN configuration
process_command "" $cmd -p $boardPL -c WWNINIT -t SW -u 2
process_command "" $cmd -p $boardPL -c WWNCONF -t SW -u 2 -k LICENSEID -v $wwn

# miscellaneous initialization
process_command "" $cmd -p $boardPL -c INITCPCONF
process_command "" $cmd -p $boardPL -c INITFRUHIST

######################################################################
# translate the result
if [ $stat = 0 ]
then
    status=PASSED
else
    status=FAILED
fi
######################################################################

######################################################################
# display and exit
echo "wwninit.sh: DONE - $status"
exit $stat
######################################################################

